@@ -8,21 +8,25 @@
 #define FONTDIALOG_H
 
 // Qt
-#include <QDialog>
-#include <QCheckBox>
 #include <KFontChooser>
+#include <QCheckBox>
+#include <QDialog>
 #include <QDialogButtonBox>
 #include <QToolButton>
 
-namespace Konsole {
-class FontDialog: public QDialog
+namespace Konsole
+{
+class FontDialog : public QDialog
 {
     Q_OBJECT
 
 public:
     explicit FontDialog(QWidget *parent = nullptr);
 
-    QFont font() const { return _fontChooser->font(); }
+    QFont font() const
+    {
+        return _fontChooser->font();
+    }
     void setFont(const QFont &font);
 
 Q_SIGNALS:
