@@ -542,7 +542,7 @@ void Konsole::ViewSplitterHandle::mouseMoveEvent(QMouseEvent *ev)
 
 void Konsole::ViewSplitterHandle::mouseDoubleClickEvent(QMouseEvent *ev)
 {
-    auto parentSplitter = qobject_cast<ViewSplitter*>(parentWidget());
+    auto parentSplitter = qobject_cast<ViewSplitter *>(parentWidget());
 
     if (parentSplitter->count() > 1) {
         for (int i = 1; i < parentSplitter->count(); i++) {
@@ -550,9 +550,11 @@ void Konsole::ViewSplitterHandle::mouseDoubleClickEvent(QMouseEvent *ev)
                 continue;
             }
             if (orientation() == Qt::Horizontal) {
-                moveSplitter(parentSplitter->widget(i - 1)->pos().x() + ((parentSplitter->widget(i)->pos().x() + parentSplitter->widget(i)->width() - (parentSplitter->widget(i - 1)->pos().x())) / 2));
+                moveSplitter(parentSplitter->widget(i - 1)->pos().x()
+                             + ((parentSplitter->widget(i)->pos().x() + parentSplitter->widget(i)->width() - (parentSplitter->widget(i - 1)->pos().x())) / 2));
             } else {
-                moveSplitter(parentSplitter->widget(i - 1)->pos().y() + ((parentSplitter->widget(i)->pos().y() + parentSplitter->widget(i)->height() - (parentSplitter->widget(i - 1)->pos().y())) / 2));
+                moveSplitter(parentSplitter->widget(i - 1)->pos().y()
+                             + ((parentSplitter->widget(i)->pos().y() + parentSplitter->widget(i)->height() - (parentSplitter->widget(i - 1)->pos().y())) / 2));
             }
             break;
         }
